tour-guide
==========

A Wagtail app for navigation components. Please bear with us while we prepare more detailed documentation.

Compatibility
-------------

`tour-guide`' major.minor version number indicates the Wagtail release it is compatible with. Currently this is Wagtail 4.1.x

Installation
------------

1. Install using `pip`:
  ```shell
  pip install tour-guide
  ```
2. Add
   `tour_guide` to your `INSTALLED_APPS` setting:
   ```python
   INSTALLED_APPS = [
     # ...
     'tour_guide'
     # ...
   ]
   ```
